@@ -6,6 +6,7 @@ void gram_INCWSLEVEL()
     parser_empty_parlist(&parser);
     parser_inc_ws_level(&parser);
     if (message_show(MSG_NOTICE))
-        message("INCWSLEVEL: DEF level = %d", parser_ws_level(&parser));
+        message("INCWSLEVEL: DEF level = %u", 
+                                 (unsigned)parser_ws_level(&parser));
     parser_pop_fun();
 }
